interface Options {
    version: Version;
    popup: 'classic' | 'inline' | 'wiki';
    darkTheme: boolean;
    bu_ignore: string[];
    bu_allow: string[];
    buid: string | false;
    ignoreCase: boolean;
    styles: Partial<Styles>;
}
interface Styles {
    primary: string;
    secondary: string;
    tertiary: string;
    borderRadius: string;
    boxShadow: string;
    fontSize: string;
    fontColor: string;
    headerColor: string;
    versionColor: string;
    closeColor: string;
}
type BibleApi = 'KJV' | 'ASV' | 'LSV' | 'WEB';
type Bolls = 'ESV' | 'NIV' | 'MSG' | 'NLT' | 'AMP' | 'NASB';
type Version = BibleApi | Bolls;

declare class BibleUp {
    #private;
    constructor(element: HTMLElement, options: Partial<Options>);
    /**
     * Returns BibleUp Options for present class instance
     * @returns {Options}
     */
    get getOptions(): Options;
    /**
     * Activates a BibleUp instance.
     */
    create(): void;
    /**
     * This method destoys BibleUp instance and removes the links and popup from the page
     * @param force - Specify whether to totally destroy bibleup instance, and refresh() won't work anymore. when set to false, this will preserve popup container and bibleup tagging can be resumed with refresh() method
     */
    destroy(force?: boolean): void;
    /**
     * Modifies the options of a BibleUp instance
     * @param options New BibleUp Options
     * @param element The new element to search, if specified; else, the element specified during BibleUp
     * instantiation will be searched again
     * @param force If false, previous BibleUp options will be merged with new options passed.
     * If force is set to true, the options passed into this method will totally overwrite previous options
     */
    refresh(options?: Partial<Options>, force?: boolean, element?: HTMLElement): void;
}

export { BibleUp as default };
